@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-date
 version: 0.0.6.1
-id: http-date-0.0.6.1-76d33a88e482198cd21e4dd41e428e52
-key: httpd_7IrL9RiTxaNIX0MK2GbWmG
+id: http-date-0.0.6.1-fcef85ec3f020c9d6f587d45aa9f4919
+key: httpd_HmOadmSM4bG6oZrvnQCYvn
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: HTTP Date parser/formatter
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http-date-0.0.6.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http-date-0.0.6.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http-date-0.0.6.1
-hs-libraries: HShttp-date-0.0.6.1-7IrL9RiTxaNIX0MK2GbWmG
+hs-libraries: HShttp-date-0.0.6.1-HmOadmSM4bG6oZrvnQCYvn
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
-    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
+    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
 haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
